==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_managedblockchain_query/paginator.py <==
"""
Type annotations for managedblockchain-query service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_managedblockchain_query.client import ManagedBlockchainQueryClient
    from types_boto3_managedblockchain_query.paginator import (
        ListAssetContractsPaginator,
        ListFilteredTransactionEventsPaginator,
        ListTokenBalancesPaginator,
        ListTransactionEventsPaginator,
        ListTransactionsPaginator,
    )

    session = Session()
    client: ManagedBlockchainQueryClient = session.client("managedblockchain-query")

    list_asset_contracts_paginator: ListAssetContractsPaginator = client.get_paginator("list_asset_contracts")
    list_filtered_transaction_events_paginator: ListFilteredTransactionEventsPaginator = client.get_paginator("list_filtered_transaction_events")
    list_token_balances_paginator: ListTokenBalancesPaginator = client.get_paginator("list_token_balances")
    list_transaction_events_paginator: ListTransactionEventsPaginator = client.get_paginator("list_transaction_events")
    list_transactions_paginator: ListTransactionsPaginator = client.get_paginator("list_transactions")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListAssetContractsInputListAssetContractsPaginateTypeDef,
    ListAssetContractsOutputTypeDef,
    ListFilteredTransactionEventsInputListFilteredTransactionEventsPaginateTypeDef,
    ListFilteredTransactionEventsOutputTypeDef,
    ListTokenBalancesInputListTokenBalancesPaginateTypeDef,
    ListTokenBalancesOutputTypeDef,
    ListTransactionEventsInputListTransactionEventsPaginateTypeDef,
    ListTransactionEventsOutputTypeDef,
    ListTransactionsInputListTransactionsPaginateTypeDef,
    ListTransactionsOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListAssetContractsPaginator",
    "ListFilteredTransactionEventsPaginator",
    "ListTokenBalancesPaginator",
    "ListTransactionEventsPaginator",
    "ListTransactionsPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListAssetContractsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListAssetContracts.html#ManagedBlockchainQuery.Paginator.ListAssetContracts)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listassetcontractspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAssetContractsInputListAssetContractsPaginateTypeDef]
    ) -> _PageIterator[ListAssetContractsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListAssetContracts.html#ManagedBlockchainQuery.Paginator.ListAssetContracts.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listassetcontractspaginator)
        """


class ListFilteredTransactionEventsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListFilteredTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListFilteredTransactionEvents)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listfilteredtransactioneventspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListFilteredTransactionEventsInputListFilteredTransactionEventsPaginateTypeDef
        ],
    ) -> _PageIterator[ListFilteredTransactionEventsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListFilteredTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListFilteredTransactionEvents.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listfilteredtransactioneventspaginator)
        """


class ListTokenBalancesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTokenBalances.html#ManagedBlockchainQuery.Paginator.ListTokenBalances)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtokenbalancespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTokenBalancesInputListTokenBalancesPaginateTypeDef]
    ) -> _PageIterator[ListTokenBalancesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTokenBalances.html#ManagedBlockchainQuery.Paginator.ListTokenBalances.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtokenbalancespaginator)
        """


class ListTransactionEventsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListTransactionEvents)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactioneventspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTransactionEventsInputListTransactionEventsPaginateTypeDef]
    ) -> _PageIterator[ListTransactionEventsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListTransactionEvents.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactioneventspaginator)
        """


class ListTransactionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactions.html#ManagedBlockchainQuery.Paginator.ListTransactions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactionspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTransactionsInputListTransactionsPaginateTypeDef]
    ) -> _PageIterator[ListTransactionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactions.html#ManagedBlockchainQuery.Paginator.ListTransactions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactionspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_managedblockchain_query/paginator.py <==
"""
Type annotations for managedblockchain-query service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_managedblockchain_query.client import ManagedBlockchainQueryClient
    from types_boto3_managedblockchain_query.paginator import (
        ListAssetContractsPaginator,
        ListFilteredTransactionEventsPaginator,
        ListTokenBalancesPaginator,
        ListTransactionEventsPaginator,
        ListTransactionsPaginator,
    )

    session = Session()
    client: ManagedBlockchainQueryClient = session.client("managedblockchain-query")

    list_asset_contracts_paginator: ListAssetContractsPaginator = client.get_paginator("list_asset_contracts")
    list_filtered_transaction_events_paginator: ListFilteredTransactionEventsPaginator = client.get_paginator("list_filtered_transaction_events")
    list_token_balances_paginator: ListTokenBalancesPaginator = client.get_paginator("list_token_balances")
    list_transaction_events_paginator: ListTransactionEventsPaginator = client.get_paginator("list_transaction_events")
    list_transactions_paginator: ListTransactionsPaginator = client.get_paginator("list_transactions")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListAssetContractsInputPaginateTypeDef,
    ListAssetContractsOutputTypeDef,
    ListFilteredTransactionEventsInputPaginateTypeDef,
    ListFilteredTransactionEventsOutputTypeDef,
    ListTokenBalancesInputPaginateTypeDef,
    ListTokenBalancesOutputTypeDef,
    ListTransactionEventsInputPaginateTypeDef,
    ListTransactionEventsOutputTypeDef,
    ListTransactionsInputPaginateTypeDef,
    ListTransactionsOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListAssetContractsPaginator",
    "ListFilteredTransactionEventsPaginator",
    "ListTokenBalancesPaginator",
    "ListTransactionEventsPaginator",
    "ListTransactionsPaginator",
)


if TYPE_CHECKING:
    _ListAssetContractsPaginatorBase = Paginator[ListAssetContractsOutputTypeDef]
else:
    _ListAssetContractsPaginatorBase = Paginator  # type: ignore[assignment]


class ListAssetContractsPaginator(_ListAssetContractsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListAssetContracts.html#ManagedBlockchainQuery.Paginator.ListAssetContracts)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listassetcontractspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAssetContractsInputPaginateTypeDef]
    ) -> PageIterator[ListAssetContractsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListAssetContracts.html#ManagedBlockchainQuery.Paginator.ListAssetContracts.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listassetcontractspaginator)
        """


if TYPE_CHECKING:
    _ListFilteredTransactionEventsPaginatorBase = Paginator[
        ListFilteredTransactionEventsOutputTypeDef
    ]
else:
    _ListFilteredTransactionEventsPaginatorBase = Paginator  # type: ignore[assignment]


class ListFilteredTransactionEventsPaginator(_ListFilteredTransactionEventsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListFilteredTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListFilteredTransactionEvents)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listfilteredtransactioneventspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFilteredTransactionEventsInputPaginateTypeDef]
    ) -> PageIterator[ListFilteredTransactionEventsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListFilteredTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListFilteredTransactionEvents.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listfilteredtransactioneventspaginator)
        """


if TYPE_CHECKING:
    _ListTokenBalancesPaginatorBase = Paginator[ListTokenBalancesOutputTypeDef]
else:
    _ListTokenBalancesPaginatorBase = Paginator  # type: ignore[assignment]


class ListTokenBalancesPaginator(_ListTokenBalancesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTokenBalances.html#ManagedBlockchainQuery.Paginator.ListTokenBalances)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtokenbalancespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTokenBalancesInputPaginateTypeDef]
    ) -> PageIterator[ListTokenBalancesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTokenBalances.html#ManagedBlockchainQuery.Paginator.ListTokenBalances.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtokenbalancespaginator)
        """


if TYPE_CHECKING:
    _ListTransactionEventsPaginatorBase = Paginator[ListTransactionEventsOutputTypeDef]
else:
    _ListTransactionEventsPaginatorBase = Paginator  # type: ignore[assignment]


class ListTransactionEventsPaginator(_ListTransactionEventsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListTransactionEvents)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactioneventspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTransactionEventsInputPaginateTypeDef]
    ) -> PageIterator[ListTransactionEventsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactionEvents.html#ManagedBlockchainQuery.Paginator.ListTransactionEvents.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactioneventspaginator)
        """


if TYPE_CHECKING:
    _ListTransactionsPaginatorBase = Paginator[ListTransactionsOutputTypeDef]
else:
    _ListTransactionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListTransactionsPaginator(_ListTransactionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactions.html#ManagedBlockchainQuery.Paginator.ListTransactions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTransactionsInputPaginateTypeDef]
    ) -> PageIterator[ListTransactionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/managedblockchain-query/paginator/ListTransactions.html#ManagedBlockchainQuery.Paginator.ListTransactions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_managedblockchain_query/paginators/#listtransactionspaginator)
        """
